@@ -3,8 +3,6 @@ use strict;
 use File::Spec;
 use Config;
 
-my @alt_transfer = qw/altname incsuffix libbase/;
-
 sub probe {
   my ($class, $req) = @_;
 
@@ -19,25 +17,8 @@ sub probe {
     $result = _probe_pkg($req);
   }
   if (!$result && $req->{inccheck} && ($req->{libcheck} || $req->{libbase})) {
-    $req->{altname} ||= "main";
     $result = _probe_check($req);
   }
-  if (!$result && $req->{alternatives}) {
-  ALTCHECK:
-    my $index = 1;
-    for my $alt (@{$req->{alternatives}}) {
-      $req->{altname} ||= "alt $index";
-      $req->{verbose}
-	and print "$req->{name}: Trying alternative $index\n";
-      my %work = %$req;
-      for my $key (@alt_transfer) {
-	exists $alt->{$key} and $work{$key} = $alt->{$key};
-      }
-      $result = _probe_check(\%work)
-	and last;
-      ++$index;
-    }
-  }
 
   if (!$result && $req->{testcode}) {
     $result = _probe_fake($req);
@@ -89,13 +70,6 @@ sub is_exe {
 sub _probe_pkg {
   my ($req) = @_;
 
-  # Setup pkg-config's environment variable to search non-standard paths
-  # which may be provided by --libdirs.
-  my @pkgcfg_paths = map { "$_/pkgconfig" } _lib_paths( $req );
-  push @pkgcfg_paths, $ENV{ 'PKG_CONFIG_PATH' } if $ENV{ 'PKG_CONFIG_PATH' };
-
-  local $ENV{ 'PKG_CONFIG_PATH' } = join $Config{path_sep}, @pkgcfg_paths;
-
   is_exe('pkg-config') or return;
   my $redir = $^O eq 'MSWin32' ? '' : '2>/dev/null';
 
@@ -168,11 +142,7 @@ sub _probe_check {
     }
   }
 
-  my $alt = "";
-  if ($req->{alternatives}) {
-    $alt = " $req->{altname}:";
-  }
-  print "$req->{name}:$alt includes ", $found_incpath ? "" : "not ",
+  print "$req->{name}: includes ", $found_incpath ? "" : "not ",
     "found - libraries ", $found_libpath ? "" : "not ", "found\n";
 
   $found_libpath && $found_incpath
@@ -212,7 +182,7 @@ sub _probe_fake {
     $lopts = $req->{libbase} ? "-l$req->{libbase}" : "";
   }
   if (defined $lopts) {
-    print "$req->{name}: Checking if the compiler can find them on its own\n";
+    print "$req->{name}: Checking if the compiler can find them on it's own\n";
     return
       {
        INC => "",
@@ -232,11 +202,11 @@ sub _probe_test {
   require Devel::CheckLib;
   # setup LD_RUN_PATH to match link time
   my ($extra, $bs_load, $ld_load, $ld_run_path) =
-    ExtUtils::Liblist->ext($result->{LIBS}, $req->{verbose});
+    ExtUtils::Liblist->ext($req->{LIBS}, $req->{verbose});
   local $ENV{LD_RUN_PATH};
 
   if ($ld_run_path) {
-    print "Setting LD_RUN_PATH=$ld_run_path for $req->{name} probe\n"
+    print "Setting LD_RUN_PATH=$ld_run_path for TIFF probe\n"
       if $req->{verbose};
     $ENV{LD_RUN_PATH} = $ld_run_path;
   }
@@ -248,7 +218,6 @@ sub _probe_test {
 	 INC => $result->{INC},
 	 header => $req->{testcodeheaders},
 	 function => $req->{testcode},
-	 prologue => $req->{testcodeprologue},
 	);
   unless ($good) {
     print "$req->{name}: Test code failed: $@";
@@ -269,19 +238,17 @@ sub _lib_paths {
      (
       map { split ' ' }
       grep $_,
-      @Config{qw/loclibpth libpth libspath/}
+      @Config{qw/loclibpath libpth libspath/}
      ),
      $^O eq "MSWin32" ? $ENV{LIB} : "",
      $^O eq "cygwin" ? "/usr/lib/w32api" : "",
-     "/usr/lib",
-     "/usr/local/lib",
     );
 }
 
 sub _inc_paths {
   my ($req) = @_;
 
-  my @paths = _paths
+  return _paths
     (
      $ENV{IM_INCPATH},
      $req->{incpath},
@@ -290,17 +257,11 @@ sub _inc_paths {
      (
       map { split ' ' }
       grep $_,
-      @Config{qw/locincpth incpath/}
+      @Config{qw/locincpath incpath/}
      ),
      "/usr/include",
      "/usr/local/include",
     );
-
-  if ($req->{incsuffix}) {
-    @paths = map File::Spec->catdir($_, $req->{incsuffix}), @paths;
-  }
-
-  return @paths;
 }
 
 sub _paths {
@@ -439,11 +400,6 @@ need to set C<testcodeheaders>.
 
 =item *
 
-C<testcodeprologue> - C code to insert between the headers and the
-main function.
-
-=item *
-
 C<incpath> - C<$Config{path_sep}> separated list of header file
 directories to check.
 
